summaryrefslogtreecommitdiff
path: root/hw
diff options
context:
space:
mode:
authorhathach <[email protected]>2023-05-10 11:15:11 +0700
committerhathach <[email protected]>2023-05-10 11:15:11 +0700
commitc0e4c02b9d70240b97aa4924e6002ccb3d8057dd (patch)
treec3d860b46a9db5acd23579f36a5c8ac14cf988e0 /hw
parentbc579c045e5d62050f0b58f20fd28fb71e4070a8 (diff)
allow imxrt build with dual exmaples
Diffstat (limited to 'hw')
-rw-r--r--hw/bsp/family_support.cmake4
-rw-r--r--hw/bsp/imxrt/family.cmake4
2 files changed, 6 insertions, 2 deletions
diff --git a/hw/bsp/imxrt/family.cmake b/hw/bsp/imxrt/family.cmake
index 85ad104a0..b510c064e 100644
--- a/hw/bsp/imxrt/family.cmake
+++ b/hw/bsp/imxrt/family.cmake
@@ -173,3 +173,7 @@ endfunction()
function(family_configure_host_example TARGET)
family_configure_target(${TARGET})
endfunction()
+
+function(family_configure_dual_usb_example TARGET)
+ family_configure_target(${TARGET})
+endfunction()
diff --git a/hw/bsp/family_support.cmake b/hw/bsp/family_support.cmake
index 26baa6365..01e7bb018 100644
--- a/hw/bsp/family_support.cmake
+++ b/hw/bsp/family_support.cmake
@@ -27,8 +27,8 @@ if (NOT TARGET _family_support_marker)
foreach(MCU IN LISTS FAMILY_MCUS)
# For each line in only.txt
foreach(_line ${ONLYS_LINES})
- # If mcu:xxx exists for this mcu then include
- if (${_line} STREQUAL "mcu:${MCU}")
+ # If mcu:xxx exists for this mcu or board:xxx then include
+ if (${_line} STREQUAL "mcu:${MCU}" OR ${_line} STREQUAL "board:${BOARD}")
set(${RESULT} 1 PARENT_SCOPE)
return()
endif()